@@ -6,7 +6,7 @@ Kafka::Consumer - Perl interface for Kafka consumer client.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Consumer> version 0.8007 .
+This documentation refers to C<Kafka::Consumer> version 0.8008 .
 
 =cut
 
@@ -18,7 +18,7 @@ use warnings;
 
 # ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '0.8007';
+our $VERSION = '0.8008';
 
 #-- load the modules -----------------------------------------------------------
 
@@ -40,7 +40,7 @@ use Kafka qw(
     $DEFAULT_MAX_NUMBER_OF_OFFSETS
     $DEFAULT_MAX_WAIT_TIME
     %ERROR
-    $ERROR_COMPRESSED_PAYLOAD
+    $ERROR_METADATA_ATTRIBUTES
     $ERROR_MISMATCH_ARGUMENT
     $ERROR_PARTITION_DOES_NOT_MATCH
     $ERROR_TOPIC_DOES_NOT_MATCH
@@ -153,7 +153,7 @@ Provides an object-oriented API for consuming messages.
 
 =item *
 
-Provides Kafka FETCH and OFFSETS requests (FETCH does not support compression codec).
+Provides Kafka FETCH and OFFSETS requests.
 
 =item *
 
@@ -314,7 +314,7 @@ The following methods are defined for the C<Kafka::Consumer> class:
 
 #-- public methods -------------------------------------------------------------
 
-=head3 C<fetch( $topic, $partition, $offset, $max_size )>
+=head3 C<fetch( $topic, $partition, $start_offset, $max_size )>
 
 Get a list of messages to consume one by one up to C<$max_size> bytes.
 
@@ -332,7 +332,7 @@ The C<$topic> must be a normal non-false string of non-zero length.
 
 The C<$partition> must be a non-negative integer.
 
-=item C<$offset>
+=item C<$start_offset>
 
 Offset in topic and partition to start from (64-bit integer).
 
@@ -351,14 +351,15 @@ can be imported from L<Kafka|Kafka> module.
 
 =cut
 sub fetch {
-    my ( $self, $topic, $partition, $offset, $max_size ) = @_;
+    my ( $self, $topic, $partition, $start_offset, $max_size, $_return_all ) = @_;
+    # Special argument: $_return_all - return redundant messages sent out of a compressed package posts
 
     $self->_error( $ERROR_MISMATCH_ARGUMENT, '$topic' )
         unless defined( $topic ) && ( $topic eq q{} || defined( _STRING( $topic ) ) ) && !utf8::is_utf8( $topic );
     $self->_error( $ERROR_MISMATCH_ARGUMENT, '$partition' )
         unless defined( $partition ) && isint( $partition );
     $self->_error( $ERROR_MISMATCH_ARGUMENT, '$offset' )
-        unless defined( $offset ) && ( ( _isbig( $offset ) && $offset >= 0 ) || defined( _NONNEGINT( $offset ) ) );
+        unless defined( $start_offset ) && ( ( _isbig( $start_offset ) && $start_offset >= 0 ) || defined( _NONNEGINT( $start_offset ) ) );
     $self->_error( $ERROR_MISMATCH_ARGUMENT, "\$max_size ($max_size)" )
         unless ( !defined( $max_size ) || ( ( _isbig( $max_size ) || _POSINT( $max_size ) ) && $max_size >= $MESSAGE_SIZE_OVERHEAD && $max_size <= $MAX_INT32 ) );
 
@@ -374,7 +375,7 @@ sub fetch {
                 partitions                  => [
                     {
                         Partition           => $partition,
-                        FetchOffset         => $offset,
+                        FetchOffset         => $start_offset,
                         MaxBytes            => $max_size // $self->{MaxBytes},
                     },
                 ],
@@ -402,7 +403,15 @@ sub fetch {
                     $offset = Kafka::Int64::intsum( $offset, 0 );
                     $next_offset = Kafka::Int64::intsum( $offset, 1 );
                 }
-                my $message_error = $Message->{Attributes} ? $ERROR{ $ERROR_COMPRESSED_PAYLOAD } : q{};
+
+                # skip previous messages of a compressed package posts
+                next if $offset < $start_offset && !$_return_all;
+
+                # According to Apache Kafka documentation:
+                # This byte holds metadata attributes about the message.
+                # The lowest 2 bits contain the compression codec used for the message.
+                # The other bits should be set to 0.
+                my $message_error = $Message->{Attributes} >> 2 ? $ERROR{ $ERROR_METADATA_ATTRIBUTES } : q{};
 
                 push( @$messages, Kafka::Message->new( {
                         Attributes          => $Message->{Attributes},
@@ -610,6 +619,11 @@ Main page at L<http://kafka.apache.org/>
 
 Kafka Protocol at L<https://cwiki.apache.org/confluence/display/KAFKA/A+Guide+To+The+Kafka+Protocol>
 
+=head1 SOURCE CODE
+
+Kafka package is hosted on GitHub:
+L<https://github.com/TrackingSoft/Kafka>
+
 =head1 AUTHOR
 
 Sergey Gladkov, E<lt>sgladkov@trackingsoft.comE<gt>
